/*
 * file CqHistoryFieldValue.java
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM 
 *
 * com.ibm.rational.wvcm.stp.cq.CqHistoryFieldValue
 *
 *  Copyright IBM Corporation 2006, 2008.  All Rights Reserved.
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or 
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */

package com.ibm.rational.wvcm.stp.cq;

import javax.wvcm.WvcmException;

import com.ibm.rational.wvcm.stpex.StpExBase;

/**
 * An extension of the CqFieldValue StpProperty interface representing the value
 * of a ClearQuest record history field. The VALUE of this property is an array
 * of strings, each representing a single event in the lifetime of the record.
 * Each event has several sub-fields indicating the time of the event, the user
 * that caused the event, initial and final states, etc. The sub-fields are
 * separated by "\t" characters.
 */
public interface CqHistoryFieldValue extends CqFieldValue<String[]>
{
    /**
     * An array of labels for the sub-fields of an event in the VALUE
     * array.
     */
    MetaPropertyName<String[]> DISPLAY_NAME_HEADER =
        new MetaPropertyName<String[]>(StpExBase.METADATA_NAMESPACE,
                                       "display-name-header");

    /**
     * Returns the value of the {@link #DISPLAY_NAME_HEADER DISPLAY_NAME_HEADER}
     * property as defined by this proxy.
     * 
     * @return A String[], each element of which contains a label for one
     *         sub-field of a history event. The length of this array defines
     *         the number of sub-fields in each String of the VALUE array.
     * 
     * @throws WvcmException if this proxy does not define a value for the
     *             {@link #DISPLAY_NAME_HEADER DISPLAY_NAME_HEADER} property.
     */
    public String[] getDisplayNameHeader() throws WvcmException;

    /**
     * An array of labels for the sub-fields of an event in the
     * {@link #HISTORIES_FOR_EXPORT} array.
     */
    MetaPropertyName<String[]> DISPLAY_NAME_HEADER_FOR_EXPORT =
        new MetaPropertyName<String[]>(StpExBase.METADATA_NAMESPACE,
                                       "display-name-header-for-export");

    /**
     * Returns the value of the
     * {@link #DISPLAY_NAME_HEADER_FOR_EXPORT DISPLAY_NAME_HEADER_FOR_EXPORT}
     * property as defined by this proxy.
     * 
     * @return A String[], each element of which contains a label for one
     *         sub-field of a history event in the {@link #HISTORIES_FOR_EXPORT}
     *         array. The length of this array defines the number of sub-fields
     *         in each String of the {@link #HISTORIES_FOR_EXPORT} array.
     * 
     * @throws WvcmException if this proxy does not define a value for the
     *             {@link #DISPLAY_NAME_HEADER_FOR_EXPORT DISPLAY_NAME_HEADER_FOR_EXPORT}
     *             property.
     */
    public String[] getDisplayNameHeaderForExport() throws WvcmException;

    /**
     * An array of the history events in a format suitable for export
     */
    MetaPropertyName<String[]> HISTORIES_FOR_EXPORT =
        new MetaPropertyName<String[]>(StpExBase.METADATA_NAMESPACE,
                                       "histories-for-export");

    /**
     * Returns the value of the
     * {@link #HISTORIES_FOR_EXPORT HISTORIES_FOR_EXPORT} property as defined by
     * this proxy.
     * 
     * @return A String[], each element of which describes an event in the
     *         history of this field's record. Each event String contains
     *         sub-fields appropriate for export of the the event information.
     * 
     * @throws WvcmException if this proxy does not define a value for the
     *             {@link #HISTORIES_FOR_EXPORT HISTORIES_FOR_EXPORT} property.
     */
    public String[] getHistoriesForExport() throws WvcmException;
}
